@@ -18,30 +18,52 @@
  * author citations must be preserved.
  ***************************************************************************/
 #include <src/autopicker_mpi.h>
-
+#ifdef CUDA
+#include <src/acc/cuda/cuda_autopicker.h>
+#endif
 
 int main(int argc, char *argv[])
 {
 	AutoPickerMpi prm;
 
 	try
-    {
+	{
 		prm.read(argc, argv);
 
 		prm.initialise();
 
-		prm.run();
-    }
+#ifdef CUDA
+		if (prm.do_gpu)
+		{
+			std::stringstream didSs;
+			didSs << "APr" << prm.getRank();
+			int dev_id = prm.deviceInitialise();
+			prm.cudaPicker = (void*) new AutoPickerCuda((AutoPickerMpi*)&prm, dev_id, didSs.str().c_str() );
 
-    catch (RelionError XE)
-    {
-    	if (prm.verb > 0)
-    		prm.usage();
-        std::cout << XE;
-        MPI_Abort(MPI_COMM_WORLD, EXIT_FAILURE);
-    }
+			((AutoPickerCuda*)prm.cudaPicker)->run();
+		}
+		else
+#endif
+		{
+			prm.run();
+		}
 
-    return 0;
+		MPI_Barrier(MPI_COMM_WORLD);
+		if (prm.getRank() == 0)
+			prm.generatePDFLogfile();
+	}
 
+	catch (RelionError XE)
+	{
+		if (prm.verb > 0)
+    			//prm.usage();
+		std::cerr << XE;
+		MPI_Abort(MPI_COMM_WORLD, RELION_EXIT_FAILURE);
+
+		return RELION_EXIT_FAILURE;
+	}
+
+        MPI_Barrier(MPI_COMM_WORLD);
+	return RELION_EXIT_SUCCESS;
 }
 
