@@ -123,7 +123,7 @@ template <typename T> class Matrix2D;
  * the vector is (x, y) in R2.
  *
  * @code
- * MultidimArray< DOUBLE > v(2);
+ * MultidimArray< RFLOAT > v(2);
  * VECTOR_R2(v, 1, 2);
  * @endcode
  */
@@ -135,7 +135,7 @@ template <typename T> class Matrix2D;
  * the vector is (x, y, z) in R3.
  *
  * @code
- * MultidimArray< DOUBLE > v(3);
+ * MultidimArray< RFLOAT > v(3);
  * VECTOR_R2(v, 1, 2, 1);
  * @endcode
  */
@@ -144,7 +144,7 @@ template <typename T> class Matrix2D;
 
 /** Adding two R2 vectors (a=b+c)
  * @code
- * MultidimArray< DOUBLE > a(2), b(2), c(2);
+ * MultidimArray< RFLOAT > a(2), b(2), c(2);
  * ...;
  * V2_PLUS_V2(a, b, c);
  * @endcode
@@ -155,7 +155,7 @@ template <typename T> class Matrix2D;
 
 /** Substracting two R2 vectors (a=b-c)
  * @code
- * MultidimArray< DOUBLE > a(2), b(2), c(2);
+ * MultidimArray< RFLOAT > a(2), b(2), c(2);
  * ...;
  * V2_MINUS_V2(a, b, c);
  * @endcode
@@ -166,13 +166,13 @@ template <typename T> class Matrix2D;
 
 /** Adding/substracting a constant to a R2 vector (a=b-k).
  * @code
- * MultidimArray< DOUBLE > a(2), b(2);
- * DOUBLE k;
+ * MultidimArray< RFLOAT > a(2), b(2);
+ * RFLOAT k;
  * ...;
  * V2_PLUS_CT(a, b, k);
  *
- * MultidimArray< DOUBLE > a(2), b(2);
- * DOUBLE k;
+ * MultidimArray< RFLOAT > a(2), b(2);
+ * RFLOAT k;
  * ...;
  * V2_PLUS_CT(a, b, -k);
  * @endcode
@@ -183,13 +183,13 @@ template <typename T> class Matrix2D;
 
 /** Multiplying/dividing by a constant a R2 vector (a=b*k)
  * @code
- * MultidimArray< DOUBLE > a(2), b(2);
- * DOUBLE k;
+ * MultidimArray< RFLOAT > a(2), b(2);
+ * RFLOAT k;
  * ...;
  * V2_BY_CT(a, b, k);
  *
- * MultidimArray< DOUBLE > a(2), b(2);
- * DOUBLE k;
+ * MultidimArray< RFLOAT > a(2), b(2);
+ * RFLOAT k;
  * ...;
  * V2_BY_CT(a, b, 1/k);
  * @endcode
@@ -200,7 +200,7 @@ template <typename T> class Matrix2D;
 
 /** Adding two R3 vectors (a=b+c)
  * @code
- * MultidimArray< DOUBLE > a(3), b(3), c(3);
+ * MultidimArray< RFLOAT > a(3), b(3), c(3);
  * ...;
  * V3_PLUS_V3(a, b, c);
  * @endcode
@@ -212,7 +212,7 @@ template <typename T> class Matrix2D;
 
 /** Substracting two R3 vectors (a=b-c)
  * @code
- * MultidimArray< DOUBLE > a(3), b(3), c(3);
+ * MultidimArray< RFLOAT > a(3), b(3), c(3);
  * ...;
  * V3_MINUS_V3(a, b, c);
  * @endcode
@@ -224,13 +224,13 @@ template <typename T> class Matrix2D;
 
 /** Adding/substracting a constant to a R3 vector (a=b-k)
  * @code
- * MultidimArray< DOUBLE > a(3), b(3);
- * DOUBLE k;
+ * MultidimArray< RFLOAT > a(3), b(3);
+ * RFLOAT k;
  * ...;
  * V3_PLUS_CT(a, b, k);
  *
- * MultidimArray< DOUBLE > a(3), b(3);
- * DOUBLE k;
+ * MultidimArray< RFLOAT > a(3), b(3);
+ * RFLOAT k;
  * ...;
  * V3_PLUS_CT(a, b, -k);
  * @endcode
@@ -242,13 +242,13 @@ template <typename T> class Matrix2D;
 
 /** Multiplying/dividing by a constant a R3 vector (a=b*k)
  * @code
- * MultidimArray< DOUBLE > a(3), b(3);
- * DOUBLE k;
+ * MultidimArray< RFLOAT > a(3), b(3);
+ * RFLOAT k;
  * ...;
  * V3_BY_CT(a, b, k);
  *
- * MultidimArray< DOUBLE > a(3), b(3);
- * DOUBLE k;
+ * MultidimArray< RFLOAT > a(3), b(3);
+ * RFLOAT k;
  * ...;
  * V3_BY_CT(a, b, 1/k);
  * @endcode
@@ -289,8 +289,8 @@ public:
      * vector (by default), or a row one.
      *
      * @code
-     * Matrix1D< DOUBLE > v1;
-     * Matrix1D< DOUBLE > v1(true);
+     * Matrix1D< RFLOAT > v1;
+     * Matrix1D< RFLOAT > v1(true);
      * // both are examples of empty column vectors
      *
      * Matrix1D< int > v1(false);
@@ -311,8 +311,8 @@ public:
      * one.
      *
      * @code
-     * Matrix1D< DOUBLE > v1(6);
-     * Matrix1D< DOUBLE > v1(6, 'y');
+     * Matrix1D< RFLOAT > v1(6);
+     * Matrix1D< RFLOAT > v1(6, 'y');
      * // both are examples of column vectors of dimensions 6
      *
      * Matrix1D< int > v1('n');
@@ -332,7 +332,7 @@ public:
      * different memory assignment.
      *
      * @code
-     * Matrix1D< DOUBLE > v2(v1);
+     * Matrix1D< RFLOAT > v2(v1);
      * @endcode
      */
     Matrix1D(const Matrix1D<T>& v)
@@ -567,7 +567,7 @@ public:
     /** Same value in all components.
      *
      * The constant must be of a type compatible with the array type, ie,
-     * you cannot  assign a DOUBLE to an integer array without a casting.
+     * you cannot  assign a RFLOAT to an integer array without a casting.
      * It is not an error if the array is empty, then nothing is done.
      *
      * @code
@@ -629,7 +629,7 @@ public:
      */
     Matrix1D<T> operator*(T op1) const
     {
-        Matrix1D<T> tmp(*this);
+    	Matrix1D<T> tmp(*this);
         for (int i=0; i < vdim; i++)
         	tmp.vdata[i] = vdata[i] * op1;
         return tmp;
@@ -771,6 +771,9 @@ public:
      */
      Matrix1D<T> operator*(const Matrix1D<T>& op1) const
     {
+         if (vdim != op1.vdim)
+             REPORT_ERROR("Not same sizes in vector multiplication");
+
          Matrix1D<T> tmp(op1);
          for (int i=0; i < vdim; i++)
          	tmp.vdata[i] = vdata[i] * op1.vdata[i];
@@ -781,6 +784,9 @@ public:
      */
      Matrix1D<T> operator/(const Matrix1D<T>& op1) const
     {
+         if (vdim != op1.vdim)
+             REPORT_ERROR("Not same sizes in vector division");
+
          Matrix1D<T> tmp(op1);
          for (int i=0; i < vdim; i++)
          	tmp.vdata[i] = vdata[i] / op1.vdata[i];
@@ -790,6 +796,9 @@ public:
      */
      Matrix1D<T> operator+(const Matrix1D<T>& op1) const
     {
+         if (vdim != op1.vdim)
+             REPORT_ERROR("Not same sizes in vector summation");
+
          Matrix1D<T> tmp(op1);
          for (int i=0; i < vdim; i++)
          	tmp.vdata[i] = vdata[i] + op1.vdata[i];
@@ -800,6 +809,9 @@ public:
      */
      Matrix1D<T> operator-(const Matrix1D<T>& op1) const
     {
+         if (vdim != op1.vdim)
+             REPORT_ERROR("Not same sizes in vector subtraction");
+
          Matrix1D<T> tmp(op1);
          for (int i=0; i < vdim; i++)
          	tmp.vdata[i] = vdata[i] - op1.vdata[i];
@@ -810,6 +822,9 @@ public:
      */
     void operator*=(const Matrix1D<T>& op1)
     {
+        if (vdim != op1.vdim)
+             REPORT_ERROR("Not same sizes in vector multiplication");
+
         for (int i=0; i < vdim; i++)
         	vdata[i] *= op1.vdata[i];
     }
@@ -818,6 +833,9 @@ public:
      */
     void operator/=(const Matrix1D<T>& op1)
     {
+        if (vdim != op1.vdim)
+            REPORT_ERROR("Not same sizes in vector division");
+
         for (int i=0; i < vdim; i++)
          	vdata[i] /= op1.vdata[i];
     }
@@ -826,6 +844,9 @@ public:
      */
     void operator+=(const Matrix1D<T>& op1)
     {
+        if (vdim != op1.vdim)
+             REPORT_ERROR("Not same sizes in vector summation");
+
         for (int i=0; i < vdim; i++)
         	vdata[i] += op1.vdata[i];
     }
@@ -834,6 +855,9 @@ public:
      */
     void operator-=(const Matrix1D<T>& op1)
     {
+        if (vdim != op1.vdim)
+            REPORT_ERROR("Not same sizes in vector subtraction");
+
         for (int i=0; i < vdim; i++)
          	vdata[i] -= op1.vdata[i];
     }
@@ -1009,18 +1033,18 @@ public:
      * This function returns the sum of all internal values.
      *
      * @code
-     * DOUBLE sum = m.sum();
+     * RFLOAT sum = m.sum();
      * @endcode
      */
-    DOUBLE sum(bool average=false) const
+    RFLOAT sum(bool average=false) const
     {
-        DOUBLE sum = 0;
+        RFLOAT sum = 0;
 		for (int j = 0; j < vdim; j++)
 		{
 			sum += vdata[j];
 		}
 		if (average)
-			return sum/(DOUBLE)vdim;
+			return sum/(RFLOAT)vdim;
 		else
 			return sum;
     }
@@ -1031,12 +1055,12 @@ public:
      * power_class.
      *
      * @code
-     * DOUBLE sum2 = m.sum2();
+     * RFLOAT sum2 = m.sum2();
      * @endcode
      */
-    DOUBLE sum2() const
+    RFLOAT sum2() const
     {
-        DOUBLE sum = 0;
+        RFLOAT sum = 0;
 		for (int j = 0; j < vdim; j++)
 		{
 			sum += vdata[j] * vdata[j];
@@ -1050,10 +1074,10 @@ public:
      * components. Euclidean norm of the vector.
      *
      * @code
-     * DOUBLE mod = v.module();
+     * RFLOAT mod = v.module();
      * @endcode
      */
-    DOUBLE module() const
+    RFLOAT module() const
     {
         return sqrt(sum2());
     }
@@ -1063,16 +1087,16 @@ public:
      * Supposing this vector is in R2 this function returns the angle of this
      * vector with X axis, ie, atan2(YY(v), XX(v))
      */
-    DOUBLE angle()
+    RFLOAT angle()
     {
-        return atan2((DOUBLE) YY(*this), (DOUBLE) XX(*this));
+        return atan2((RFLOAT) YY(*this), (RFLOAT) XX(*this));
     }
 
     /** Normalize this vector, store the result here
      */
     void selfNormalize()
     {
-        DOUBLE m = module();
+        RFLOAT m = module();
         if (ABS(m) > XMIPP_EQUAL_ACCURACY)
         {
             T im=(T) (1.0/m);
@@ -1100,9 +1124,9 @@ public:
      * because the numerical method is not able to correctly estimate the
      * derivative there.
      */
-    void numericalDerivative(Matrix1D<DOUBLE> &result)
+    void numericalDerivative(Matrix1D<RFLOAT> &result)
     {
-         const DOUBLE i12=1.0/12.0;
+         const RFLOAT i12=1.0/12.0;
          result.initZeros(*this);
          for (int i=STARTINGX(*this)+2; i<=FINISHINGX(*this)-2; i++)
         	 result(i)=i12*(-(*this)(i+2)+8*(*this)(i+1)
@@ -1117,7 +1141,7 @@ public:
         else
             ostrm << std::endl;
 
-        DOUBLE max_val = ABS(v.vdata[0]);
+        RFLOAT max_val = ABS(v.vdata[0]);
 
         for (int j = 0; j < v.vdim; j++)
         {
@@ -1128,7 +1152,7 @@ public:
 
         for (int j = 0; j < v.vdim; j++)
         {
-       	 ostrm << floatToString((DOUBLE) v.vdata[j], 10, prec)
+       	 ostrm << floatToString((RFLOAT) v.vdata[j], 10, prec)
        	 << std::endl;
         }
         return ostrm;
@@ -1145,22 +1169,22 @@ public:
   * After this function the vector is (x,y) in R2.
   *
   * @code
-  * Matrix1D< DOUBLE > v = vectorR2(1, 2);
+  * Matrix1D< RFLOAT > v = vectorR2(1, 2);
   * @endcode
   */
- Matrix1D< DOUBLE > vectorR2(DOUBLE x, DOUBLE y);
+ Matrix1D< RFLOAT > vectorR2(RFLOAT x, RFLOAT y);
 
  /** Creates vector in R3.
   * After this function the vector is (x,y,z) in R3.
   *
   * @code
-  * Matrix1D< DOUBLE > v = vectorR2(1, 2, 1);
+  * Matrix1D< RFLOAT > v = vectorR2(1, 2, 1);
   * @endcode
   */
- Matrix1D< DOUBLE > vectorR3(DOUBLE x, DOUBLE y, DOUBLE z);
+ Matrix1D< RFLOAT > vectorR3(RFLOAT x, RFLOAT y, RFLOAT z);
 
  // This function is only needed for single-precision compilation
-#ifdef FLOAT_PRECISION
+#ifdef RELION_SINGLE_PRECISION
 Matrix1D< float > vectorR3(double xx, double yy, double zz);
 #endif
 
@@ -1178,7 +1202,7 @@ Matrix1D< float > vectorR3(double xx, double yy, double zz);
   * V1y*V2y + V1z*V2z.
   *
   * @code
-  * Matrix1D< DOUBLE > v1(1000);
+  * Matrix1D< RFLOAT > v1(1000);
   * v1.init_random(0, 10, "gaussian");
   * std::cout << "The power_class of this vector should be 100 and is " <<
   *     dotProduct(v1, v1) << std::endl;
@@ -1269,7 +1293,7 @@ Matrix1D< float > vectorR3(double xx, double yy, double zz);
  }
 
 /** Conversion from one type to another.
-  * If we have an integer array and we need a DOUBLE one, we can use this
+  * If we have an integer array and we need a RFLOAT one, we can use this
   * function. The conversion is done through a type casting of each element
   * If n >= 0, only the nth volumes will be converted, otherwise all NSIZE volumes
   */
