@@ -23,34 +23,27 @@
 #include "src/mpi.h"
 #include "src/ml_optimiser.h"
 
-#define MPITAG_JOB_REQUEST 0
-#define MPITAG_JOB_REPLY 1
-#define MPITAG_METADATA 2
-#define MPITAG_RANDOMSEED 3
-#define MPITAG_IMAGE 4
-#define MPITAG_PACK 5
-#define MPITAG_DOUBLE 6
-#define MPITAG_INT 7
-
-#ifdef TIMING
-	int TIMING_MPIPACK, TIMING_MPIWAIT, TIMING_MPICOMBINEDISC, TIMING_MPICOMBINENETW, TIMING_MPISLAVEWORK;
-	int TIMING_MPISLAVEWAIT1, TIMING_MPISLAVEWAIT2, TIMING_MPISLAVEWAIT3;
-#endif
+// definition of MPITAG has been moved to header mpi.h
 
 class MlOptimiserMpi: public MlOptimiser
 {
-
-private:
-	MpiNode *node;
+	std::vector<int> cudaDeviceShares;
 
 public:
+	MpiNode *node;
 
 #ifdef TIMINGMPI
     int MPIR_PACK, MPIR_ALLREDUCE, MPIR_UNPACK, MPIR_EXP, MPIR_MAX, MPIR_BCAST;
 #endif
 
-    // Name of the directory to write temporary files to
-    FileName fn_scratch;
+    // For debugging: keep temporary/debug weight and data mrc files
+    bool do_keep_debug_reconstruct_files;
+
+    // For debugging: halt all slaves except this one
+    int halt_all_slaves_except_this;
+
+    // Original verb
+    int ori_verb;
 
 	/** Destructor, calls MPI_Finalize */
     ~MlOptimiserMpi()
@@ -76,7 +69,7 @@ public:
     void initialiseWorkLoad();
 
     /** Perform individual power spectra calculation in parallel */
-    void calculateSumOfPowerSpectraAndAverageImage(MultidimArray<DOUBLE> &Mavg);
+    void calculateSumOfPowerSpectraAndAverageImage(MultidimArray<RFLOAT> &Mavg);
 
     /** Expectation
      *  This cares care of gathering all weighted sums after the expectation
@@ -106,6 +99,11 @@ public:
      */
     void maximization();
 
+    /** Perform unregularized reconstruction
+      * With the aim of performing solvent mask corrected FSC inside the auto-refine
+      */
+    void reconstructUnregularisedMapAndCalculateSolventCorrectedFSC();
+
     /**
      *  Write temporary data and weight arrays from the backprojector to disc to allow unregularized reconstructions
      */
@@ -133,7 +131,6 @@ public:
     void iterate();
 
 
-
 };
 
 
