@@ -63,12 +63,14 @@
 
 /** Removes all occurrences of 'character' from the string no matter
 where they are */
-std::string removeChar( const std::string& str, char character );
+std::string removeChar(const std::string &str, char character);
 
 /** Removes escaped symbols ESC+n, t, v, b, r, f, and a
  * Note that tabs are replaced by spaces.
  * */
-std::string unescape( const std::string& str );
+std::string unescape(const std::string &str);
+
+void escapeStringForSTAR(std::string &value);
 
 /** Best precision for a float number.
  *
@@ -106,16 +108,31 @@ std::string unescape( const std::string& str );
  */
 int bestPrecision(float F, int _width);
 
-/** String (char*) to DOUBLE conversion.
+bool isNumber(std::string);
+
+/** String (char*) to double conversion.
  *
  * @code
- * DOUBLE key = textToDOUBLE(firstToken(line), 1602, "Error reading key");
+ * RFLOAT key = textToDouble(firstToken(line), 1602, "Error reading key");
  * @endcode
  */
-DOUBLE textToDOUBLE(const char* str,
+double textToDouble(const char* str,
                     int _errno = 2101,
                     std::string errmsg = "Error in textToDouble");
 
+/** String (STL) to double conversion.
+ *
+ * @code
+ * double key = textToDouble(str, 1602, "Error reading key");
+ * @endcode
+ */
+inline double textToDouble(const std::string& str,
+                         int _errno = 2101,
+                         std::string errmsg = "Error in textToDouble")
+{
+    return textToDouble(str.c_str(), _errno, errmsg);
+}
+
 /** String (char*) to float conversion.
  *
  * @code
@@ -162,6 +179,29 @@ inline int textToInteger(const std::string& str,
     return textToInteger(str.c_str(), _errno, errmsg);
 }
 
+/** String (char*) to boolean conversion.
+ *
+ * @code
+ * bool param_no = textToBool(nextToken(), 1602, "Error reading boolean parameters")
+ * @endcode
+ */
+bool textToBool(const char* str,
+                  int _errno = 2102,
+                  std::string errmsg = "Error in textToBool");
+
+/** String (STL) to boolean conversion.
+ *
+ * @code
+ * int param_no = textToBool(str, 1602, "Error reading boolean parameters")
+ * @endcode
+ */
+inline int textToBool(const std::string& str,
+                         int _errno = 2102,
+                         std::string errmsg = "Error in textToBool")
+{
+    return textToBool(str.c_str(), _errno, errmsg);
+}
+
 /** String (char*) to long long integer conversion.
  *
  * @code
@@ -173,6 +213,20 @@ long long textToLongLong(const char* str,
                          int _errno = 2102,
                          std::string errmsg = "Error in AtoL");
 
+/** String (STL) to long long conversion.
+ *
+ * @code
+ * int param_no = textToLongLong(str, 1602, "Error reading number parameters")
+ * @endcode
+ */
+inline int textToLongLong(const std::string& str,
+                         int _errno = 2102,
+                         std::string errmsg = "Error in textToInteger")
+{
+    return textToLongLong(str.c_str(), _errno, errmsg);
+}
+
+
 /** Float to string conversion.
  *
  * If precision==0 the precision is automatically computed in such a way that
@@ -257,7 +311,7 @@ std::string removeSpaces(const std::string& _str);
 
 /** Remove quotes.
  *
- * This function removes the first character if it is a DOUBLE or single quote,
+ * This function removes the first character if it is a RFLOAT or single quote,
  * as well as the last character. The char pointer might be moved.
  *
  * @code
@@ -359,6 +413,8 @@ inline char* nextToken()
  */
 std::string nextToken(const std::string& str, int& i);
 
+bool nextTokenInSTAR(const std::string& str, int& i, std::string &token);
+
 /** Get non empty string (char*).
  *
  * This function returns the first word found in the given line disregarding the
